@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2006, Tobias Klauser <tklauser@distanz.ch>
+ * Copyright (C) 2005-2007, Tobias Klauser <tklauser@distanz.ch>
  *
  * Licensed under the terms of the GNU General Public License; version 2 or later.
  */
@@ -7,6 +7,8 @@
 #ifndef _INOTAIL_H
 #define _INOTAIL_H
 
+#include <sys/types.h>
+
 /* Number of items to tail. */
 #define DEFAULT_N_LINES 10
 
@@ -17,7 +19,8 @@ enum { M_LINES, M_BYTES };
 struct file_struct {
 	char *name;		/* Name of file (or '-' for stdin) */
 	int fd;			/* File descriptor (or -1 if file is not open */
-	off_t st_size;		/* File size */
+	off_t size;		/* File size */
+	blksize_t blksize;	/* Blocksize for filesystem I/O */
 	unsigned ignore;	/* Whether to ignore the file in further processing */
 	int i_watch;		/* Inotify watch associated with file_struct */
 };
@@ -29,6 +32,8 @@ struct file_struct {
 #define IS_TAILABLE(mode) \
 	(S_ISREG(mode) || IS_PIPELIKE(mode) || S_ISCHR(mode))
 
+#define is_digit(c) ((c) >= '0' && (c) <= '9')
+
 #ifdef DEBUG
 # define dprintf(fmt, args...) fprintf(stderr, fmt, ##args)
 #else
